# powfacpy
This package is a wrapper around the Python API of PowerFactory&copy; (power system simulation software by DIgSILENT) with improved syntax and functionality compared to the native API. Please have a look at the [documentation](https://fraunhiee-unikassel-powsysstability.github.io/powfacpy/docs/) for further information. 


## Why use *powfacpy*?
There are a number of reasons why you should consider using *powfacpy*:
- Increase productivity 
- Write more readable code
- Avoid running into similar problems, errors and obscurities as other users of the python interface of *PowerFactory* before you
- Having a standard way of doing things in your organization (e.g. a standard format for simulation result export) 
- Steep learning curve for *PowerFactory* beginners (helpful tutorials)


## Contact
This package is under active development and mainly maintained by *Fraunhofer IEE*. You are welcome to contribute or feel free to get in touch (contact: simon.eberlein@iee.fraunhofer.de). 
